package br.livro.android.cap11.outros;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.HttpURLConnection;
import java.net.URL;

import android.app.Service;
import android.content.Intent;
import android.os.IBinder;
import android.util.Log;
import br.livroandroid.utils.NotificationUtil;

/**
 * Servio que faz o download de uma imagem e cria uma notificao
 * 
 * @author ricardo
 * 
 */
public class ServicoDownloadImagem extends Service {
	private final String CATEGORIA = "livro";
	private static final String URL = "http://livroandroid.com.br/imagens/livro02.png";

	@Override
	public IBinder onBind(Intent intent) {
		return null;
	}

	@Override
	public void onCreate() {
		super.onCreate();
		Log.i(CATEGORIA, "ServicoDownloadImagem > onCreate()");
	}
	
	@Override
	public int onStartCommand(Intent intent, int flags, int startId) {
		Log.i(CATEGORIA, "ServicoDownloadImagem > onStartCommand() " + startId);

		downloadImagem(URL);

		return super.onStartCommand(intent, flags, startId);
	}

	private void downloadImagem(final String urlImg) {
		new Thread() {
			@Override
			public void run() {

				try {
					Log.i(CATEGORIA, "ServicoDownloadImagem > Buscando imagem...");

					// Cria a URL
					URL u = new URL(URL);

					HttpURLConnection connection = (HttpURLConnection) u.openConnection();
					// Configura a requisio como "get"
					connection.setRequestProperty("Request-Method", "GET");
					connection.setDoInput(true);
					connection.setDoOutput(false);

					connection.connect();

					InputStream in = connection.getInputStream();

					Log.i(CATEGORIA, "ServicoDownloadImagem > Lendo imagem...");

					// String arquivo = readBufferedString(sb, in);
					byte[] bytesImagem = readBytes(in);

					Log.i(CATEGORIA, "ServicoDownloadImagem > Imagem lida com sucesso!");

					connection.disconnect();

					Log.i(CATEGORIA, "ServicoDownloadImagem > Criando notificao...");

					criarNotificacao(bytesImagem);

					Log.i(CATEGORIA, "ServicoDownloadImagem > Notificao criada com sucesso.");

					stopSelf();

				} catch (IOException e) {
					Log.e(CATEGORIA, e.getMessage(), e);
				}
			}
		}.start();
	}

	private byte[] readBytes(InputStream in) throws IOException {
		ByteArrayOutputStream bos = new ByteArrayOutputStream();
		try {
			byte[] buffer = new byte[1024];
			int len;
			while ((len = in.read(buffer)) > 0) {
				bos.write(buffer, 0, len);
			}
			byte[] bytes = bos.toByteArray();
			return bytes;
		} finally {
			bos.close();
			in.close();
		}
	}

	// Exibe a notificao
	protected void criarNotificacao(byte[] bytesImagem) {

		String mensagemBarraStatus = "Fim do download.";
		String titulo = "Download completo.";
		String mensagem = "Visualizar imagem do download.";
		Class<?> activity = VisualizarImagem.class;

		// PendingIntent para executar a Activity se o usurio selecionar a notificao
		Intent intentMensagem = new Intent(this, activity);
		intentMensagem.putExtra("imagem", bytesImagem);

		// Cria a notificao
		NotificationUtil.create(this, mensagemBarraStatus, titulo, mensagem, R.drawable.smile, R.drawable.ic_launcher, intentMensagem);
	}

	@Override
	public void onDestroy() {
		super.onDestroy();
		Log.i(CATEGORIA, "ServicoDownloadImagem > onDestroy()");
	}
}