package br.livro.android.cap16.mapview;

import java.util.List;

import android.app.AlertDialog;
import android.content.Context;
import android.content.DialogInterface;
import android.graphics.Color;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.EditText;
import br.livro.android.cap16.LatLng;
import br.livro.android.cap16.LatLngSete;
import br.livro.android.cap16.Endereco;
import br.livro.android.cap16.R;
import br.livro.android.cap16.overlay.BolaOverlay;

import com.google.android.maps.MapActivity;
import com.google.android.maps.MapController;
import com.google.android.maps.MapView;

/**
 * Permite digitar um endereo.
 * 
 * Com o endereo faz a busca no Google, e o usurio escolhe o local desejado
 * 
 * Utilizando o endereo, o convertemos para coordenadas e a rota  desenhada
 * entre o MyLocation e o endereo digitado
 * 
 * @author ricardo
 *
 */
public class TelaFormEndereco extends MapActivity implements OnClickListener {
	private static final String CATEGORIA = "livro";
	private MapController controlador;

	private MapView mapa;
	private Button btBuscarEndereco;
	private BolaOverlay bola;

	@Override
	public void onCreate(Bundle icicle) {
		super.onCreate(icicle);

		setContentView(R.layout.form_endereco);

		mapa = (MapView) findViewById(R.id.mapa);

		btBuscarEndereco = (Button) findViewById(R.id.btBuscarEndereco);
		btBuscarEndereco.setOnClickListener(this);

		mapa.setSatellite(true);
		mapa.setClickable(true);

		bola = new BolaOverlay(new LatLngSete(),Color.BLUE);
		mapa.getOverlays().add(bola);

		controlador = mapa.getController();
		controlador.setZoom(15);

		mapa.setBuiltInZoomControls(true);

		controlador.animateTo(new LatLngSete());

		mapa.invalidate();
	}

	/**
	 * @see android.view.View.OnClickListener#onClick(android.view.View)
	 */
	public void onClick(View view) {
		EditText textEndereco = (EditText) findViewById(R.id.endereco);

		String endereco = textEndereco.getText().toString();

		final List<Endereco> enderecos = Endereco.buscar(this, endereco);
		final String[] s = new String[enderecos.size()];
		int i = 0;
		for (Endereco e : enderecos) {
			s[i++] = e.getDesc();
			Log.i(CATEGORIA, e.toString());
		}

		final Context contexto = this;
		AlertDialog create = new AlertDialog.Builder(contexto)
        .setTitle("Endreo")
        .setItems(s, new DialogInterface.OnClickListener() {
            public void onClick(DialogInterface dialog, int id) {
				Endereco endereco = enderecos.get(id);
				Log.i(CATEGORIA,"Endereo lat/long: " + endereco.getLatitude() + "," + endereco.getLongitude());
				LatLng c = new LatLng(endereco);
				controlador.animateTo(c);
				bola.setGeoPoint(c);
				mapa.invalidate();
            }
        })
        .create();
		create.show();
	}
	
	@Override
	protected boolean isRouteDisplayed() {
		return false;
	}
}
