package br.livro.android.cap20.push;

import android.app.Activity;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.TextView;

/**
 * @author Ricardo Lecheta
 * 
 */
public class ExemploPushActivity extends Activity {

	private static final String TAG = "push";
	// Receiver para receber a menagem do Service por Intent
	private final BroadcastReceiver mensagemReceiver = new BroadcastReceiver() {
		@Override
		public void onReceive(Context context, Intent intent) {
			String msg = intent.getExtras().getString("msg");
			if(msg != null) {
				exibirMensagem(msg);
			}
			boolean refresh = intent.getExtras().getBoolean("refresh");
			if(refresh) {
				configurarTela();
			}
		}
	};

	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);

		setContentView(R.layout.activity_exemplo_push);

		// Botes da tela
		findViewById(R.id.btnRegistrar).setOnClickListener(onClickRegistrar());
		findViewById(R.id.btnCancelar).setOnClickListener(onClickCancelar());

		// Configura a tela
		configurarTela();
		
		// Exibe o status da ativao
		boolean ativado = GCM.isAtivo(getContext());
		if (ativado) {
			String regId = GCM.getRegistrationId(getContext());
			exibirMensagem("Device j registrado: " + regId);
		} else {
			exibirMensagem("Device no registrado, clique no boto Registrar.");
		}

		// Configura o BroadcastReceiver para receber mensagens
		registerReceiver(mensagemReceiver, new IntentFilter("RECEIVER_QUE_VAI_RECEBER_ESTA_MSG"));

		// Se existe alguma mensagem enviada pela Notification, recebe aqui
		String msg = getIntent().getStringExtra("msg");
		if (msg != null) {
			exibirMensagem(msg);
		}
	}

	private void configurarTela() {
		boolean ativado = GCM.isAtivo(getContext());
		if (ativado) {
			// J est registrado
			findViewById(R.id.btnRegistrar).setEnabled(false);
			findViewById(R.id.btnCancelar).setEnabled(true);
		} else {
			// Precisa registrar
			findViewById(R.id.btnRegistrar).setEnabled(true);
			findViewById(R.id.btnCancelar).setEnabled(false);
		}
	}

	private Context getContext() {
		return getApplicationContext();
	}

	private void exibirMensagem(String msg) {
		TextView text = (TextView) findViewById(R.id.tMsgRecebida);
		text.append(msg + "\n------------------------\n");
		Log.i(TAG,msg);
	}

	private OnClickListener onClickRegistrar() {
		return new OnClickListener() {
			@Override
			public void onClick(View v) {
				GCM.registrar(getContext(), Constants.PROJECT_NUMBER);
				exibirMensagem("Solicitao de registro disparada.");
			}
		};
	}

	private OnClickListener onClickCancelar() {
		return new OnClickListener() {
			@Override
			public void onClick(View v) {
				GCM.cancelar(getContext());
				exibirMensagem("Solicitao de cancelamento disparada.");
			}
		};
	}

	@Override
	protected void onDestroy() {
		// Cancela o receiver e encerra o servio do GCM
		unregisterReceiver(mensagemReceiver);
		GCM.onDestroy(getContext());
		super.onDestroy();
	}
}
