package br.livro.android.cap20.push;

import android.content.Context;
import android.content.Intent;
import android.util.Log;
import br.livro.android.utils.ActivityStackUtils;
import br.livro.android.utils.NotificationUtil;

import com.google.android.gcm.GCMBaseIntentService;

/**
 * IntentService responsvel por tratar as mensagens do GCM (Google Cloud
 * Messaging).
 * 
 * O mtodo onRegistered  chamado quando o registro no GCM  feito com sucesso.
 * Neste momento temos o registrationId nico do device.
 * 
 * O mtodo onMessage  chamado quando uma mensagem por push  recebida.
 * 
 * @author Ricardo Lecheta
 * 
 */
public class GCMIntentService extends GCMBaseIntentService {

	private static final String TAG = "GCMIntentService";

	public GCMIntentService() {
		super(Constants.PROJECT_NUMBER);
	}

	@Override
	protected void onRegistered(Context context, String registrationId) {
		enviarMensagemParaApp("Device registrado: registrationId = " + registrationId);
		
		reconfiguraActivity();
	}

	@Override
	protected void onUnregistered(Context context, String registrationId) {
		enviarMensagemParaApp("Device removido do registro.");
		
		reconfiguraActivity();
	}

	@Override
	protected void onMessage(Context context, Intent intent) {
		String msg = intent.getStringExtra("msg");

		enviarMensagemParaApp("Mensagem recebida: " + msg);
	}

	@Override
	public void onError(Context context, String errorId) {
		enviarMensagemParaApp("Erro: " + errorId);
	}

	private void enviarMensagemParaApp(String msg) {
		Log.i(TAG, msg);

		// Se a aplicao est aberta
		if (ActivityStackUtils.isMyApplicationTaskOnTop(this)) {
			// Dispara uma Intent para o receiver configurado na Activity
			Intent intent = new Intent("RECEIVER_QUE_VAI_RECEBER_ESTA_MSG");
			intent.putExtra("msg", msg);
			sendBroadcast(intent);

		} else {
			// Cria a notificao, e informa para abrir a activity de entrada
			Intent intent2 = new Intent(this, ExemploPushActivity.class);
			intent2.putExtra("msg", msg);
			NotificationUtil.generateNotification(this, "Nova mensagem",intent2);
		}
	}
	
	private void reconfiguraActivity() {
		// Se a aplicao est aberta
		if (ActivityStackUtils.isMyApplicationTaskOnTop(this)) {
			// Dispara uma Intent para o receiver configurado na Activity
			Intent intent = new Intent("RECEIVER_QUE_VAI_RECEBER_ESTA_MSG");
			intent.putExtra("refresh", true);
			sendBroadcast(intent);
		}
	}
}
